@@ -1,4 +1,4 @@
-use sys_metrics::{cpu::*, disks::*, host::*, memory::*};
+use sys_metrics::{cpu::*, disks::*, host::*, memory::*, network::*};
 
 #[allow(unused_must_use)]
 fn main() {
@@ -12,8 +12,11 @@ fn main() {
     dbg!(get_host_info());
     dbg!(get_hostname());
     dbg!(get_os_version());
+    dbg!(get_logged_users());
     dbg!(get_users());
     dbg!(get_uuid());
     dbg!(get_memory());
     dbg!(get_swap());
+    dbg!(has_swap());
+    dbg!(get_net_physical_iocounters());
 }
