@@ -1,7 +1,9 @@
 mod cpu_freq;
 mod cpu_stats;
+mod cpu_times;
 mod logical_count;
 
 pub use cpu_freq::*;
 pub use cpu_stats::*;
+pub use cpu_times::*;
 pub use logical_count::*;
