@@ -1,7 +1,10 @@
 use crate::host;
 use crate::memory::Swap;
 
-use std::io::{Error, ErrorKind};
+use std::{
+    fs::File,
+    io::{BufRead, BufReader, Error, ErrorKind},
+};
 
 /// Return the [Swap] struct.
 ///
@@ -27,3 +30,20 @@ pub fn get_swap() -> Result<Swap, Error> {
         used: used_swap,
     })
 }
+
+/// Determine if the system uses Swap.
+///
+/// Read /proc/swaps and count the number of lines, if more than 1 then swap is enabled.
+pub fn has_swap() -> Result<bool, Error> {
+    let file = File::open("/proc/swaps")?;
+    let mut file = BufReader::with_capacity(512, file);
+
+    let mut lines = 0u8;
+    let mut line = String::with_capacity(128);
+    while file.read_line(&mut line)? != 0 {
+        lines += 1;
+        line.clear();
+    }
+
+    Ok(lines > 1)
+}
